@@ -678,7 +678,7 @@ struct _AtkImplementorIface
 };
 
 ATK_AVAILABLE_IN_ALL
-GType atk_implementor_get_type (void) G_GNUC_CONST;
+GType atk_implementor_get_type (void);
 ATK_AVAILABLE_IN_ALL
 AtkObject*              atk_implementor_ref_accessible            (AtkImplementor *implementor);
 
@@ -766,6 +766,13 @@ AtkRole               atk_role_register                        (const gchar *nam
 ATK_AVAILABLE_IN_2_8
 const gchar*          atk_object_get_object_locale             (AtkObject   *accessible);
 
+ATK_AVAILABLE_IN_ALL
+const gchar*          atk_object_get_accessible_id             (AtkObject   *accessible);
+
+ATK_AVAILABLE_IN_ALL
+void                  atk_object_set_accessible_id             (AtkObject   *accessible,
+                                                                const gchar *name);
+
 G_END_DECLS
 
 #endif /* __ATK_OBJECT_H__ */
