@@ -636,7 +636,7 @@ gchar* atk_text_get_string_at_offset (AtkText *text,
  *
  * Gets the offset of the position of the caret (cursor).
  *
- * Returns: the character offset of the position of the caret or 0  if
+ * Returns: the character offset of the position of the caret or -1 if
  *          the caret is not located inside the element or in the case of
  *          any other failure.
  **/
@@ -652,7 +652,7 @@ atk_text_get_caret_offset (AtkText *text)
   if (iface->get_caret_offset)
     return (*(iface->get_caret_offset)) (text);
   else
-    return 0;
+    return -1;
 }
 
 /**
@@ -1359,7 +1359,7 @@ atk_text_rectangle_contain (AtkTextRectangle *clip,
 }
 
 /**
- * atk_text_scroll_substring_to (AtkText *accessible, AtkScrollType type)
+ * atk_text_scroll_substring_to:
  * @text: an #AtkText
  * @start_offset: start position
  * @end_offset: end position, or -1 for the end of the string.
@@ -1393,7 +1393,7 @@ atk_text_scroll_substring_to (AtkText       *text,
 }
 
 /**
- * atk_text_scroll_substring_to_point (AtkText *accessible, AtkScrollType type, gint x, gint y)
+ * atk_text_scroll_substring_to_point:
  * @text: an #AtkText
  * @start_offset: start position
  * @end_offset: end position, or -1 for the end of the string.
